@@ -44,6 +44,21 @@ Float = sgqlc.types.Float
 
 ID = sgqlc.types.ID
 
+class InformationSourceLoaderActualStatus(sgqlc.types.Enum):
+    __schema__ = crawlers_api_schema
+    __choices__ = ('Daily', 'EveryTwoDays', 'Never', 'Weekly')
+
+
+class InformationSourceLoaderSorting(sgqlc.types.Enum):
+    __schema__ = crawlers_api_schema
+    __choices__ = ('id', 'status')
+
+
+class InformationSourceSorting(sgqlc.types.Enum):
+    __schema__ = crawlers_api_schema
+    __choices__ = ('error', 'id', 'job', 'siteName', 'status', 'url')
+
+
 Int = sgqlc.types.Int
 
 class JSON(sgqlc.types.Scalar):
@@ -77,7 +92,7 @@ class JobStatus(sgqlc.types.Enum):
 
 class LogLevel(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('Critical', 'Debug', 'Error', 'Info', 'Warning')
+    __choices__ = ('Critical', 'Debug', 'Error', 'Info', 'Trace', 'Warning')
 
 
 class LogSorting(sgqlc.types.Enum):
@@ -128,7 +143,7 @@ String = sgqlc.types.String
 
 class TypeOfCrawl(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('Actual', 'Nothing', 'Retrospective', 'RetrospectiveAndActual')
+    __choices__ = ('Actual', 'Retrospective')
 
 
 class UnixTime(sgqlc.types.Scalar):
@@ -139,21 +154,6 @@ class Upload(sgqlc.types.Scalar):
     __schema__ = crawlers_api_schema
 
 
-class UrlLoaderActualStatus(sgqlc.types.Enum):
-    __schema__ = crawlers_api_schema
-    __choices__ = ('Daily', 'EveryTwoDays', 'Never', 'Weekly')
-
-
-class UrlLoaderSorting(sgqlc.types.Enum):
-    __schema__ = crawlers_api_schema
-    __choices__ = ('id', 'status')
-
-
-class UrlToLoaderSorting(sgqlc.types.Enum):
-    __schema__ = crawlers_api_schema
-    __choices__ = ('error', 'job', 'siteName', 'status', 'url')
-
-
 class VersionSorting(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
     __choices__ = ('createdAt', 'id', 'versionName')
@@ -230,12 +230,42 @@ class FileSettings(sgqlc.types.Input):
     is_site_name_not_exist = sgqlc.types.Field(Boolean, graphql_name='isSiteNameNotExist')
 
 
+class InformationSourceFilterSettings(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('input_value', 'status')
+    input_value = sgqlc.types.Field(String, graphql_name='inputValue')
+    status = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CollectionStatus)), graphql_name='status')
+
+
+class InformationSourceLoaderFilterSettings(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('input_value', 'type_of_crawl', 'status', 'created_by', 'changed_by', 'created_at', 'changed_at')
+    input_value = sgqlc.types.Field(String, graphql_name='inputValue')
+    type_of_crawl = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(TypeOfCrawl)), graphql_name='typeOfCrawl')
+    status = sgqlc.types.Field(CollectionStatus, graphql_name='status')
+    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
+    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
+    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
+    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+
+
+class InformationSourceLoaderInput(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('file_settings', 'urls', 'is_retrospective', 'retrospective_interval', 'actual_status')
+    file_settings = sgqlc.types.Field(FileSettings, graphql_name='fileSettings')
+    urls = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null('KeyOptionValueInput')), graphql_name='urls')
+    is_retrospective = sgqlc.types.Field(Boolean, graphql_name='isRetrospective')
+    retrospective_interval = sgqlc.types.Field('TimestampInterval', graphql_name='retrospectiveInterval')
+    actual_status = sgqlc.types.Field(InformationSourceLoaderActualStatus, graphql_name='actualStatus')
+
+
 class JobInput(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('crawler_id', 'version_id', 'priority', 'settings', 'args')
+    __field_names__ = ('crawler_id', 'version_id', 'priority', 'is_noise', 'settings', 'args')
     crawler_id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='crawlerId')
     version_id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='versionId')
     priority = sgqlc.types.Field(sgqlc.types.non_null(JobPriorityType), graphql_name='priority')
+    is_noise = sgqlc.types.Field(Boolean, graphql_name='isNoise')
     settings = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('KeyValueInputType'))), graphql_name='settings')
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('KeyValueInputType'))), graphql_name='args')
 
@@ -384,35 +414,6 @@ class TimestampInterval(sgqlc.types.Input):
     end = sgqlc.types.Field(UnixTime, graphql_name='end')
 
 
-class UrlLoaderFilterSettings(sgqlc.types.Input):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'type_of_crawl', 'status', 'created_by', 'changed_by', 'created_at', 'changed_at')
-    input_value = sgqlc.types.Field(String, graphql_name='inputValue')
-    type_of_crawl = sgqlc.types.Field(TypeOfCrawl, graphql_name='typeOfCrawl')
-    status = sgqlc.types.Field(CollectionStatus, graphql_name='status')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field(TimestampInterval, graphql_name='createdAt')
-    changed_at = sgqlc.types.Field(TimestampInterval, graphql_name='changedAt')
-
-
-class UrlLoaderInput(sgqlc.types.Input):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('file_settings', 'urls', 'is_retrospective', 'retrospective_interval', 'actual_status')
-    file_settings = sgqlc.types.Field(FileSettings, graphql_name='fileSettings')
-    urls = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(KeyOptionValueInput)), graphql_name='urls')
-    is_retrospective = sgqlc.types.Field(Boolean, graphql_name='isRetrospective')
-    retrospective_interval = sgqlc.types.Field(TimestampInterval, graphql_name='retrospectiveInterval')
-    actual_status = sgqlc.types.Field(UrlLoaderActualStatus, graphql_name='actualStatus')
-
-
-class UrlToLoaderFilterSettings(sgqlc.types.Input):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'status')
-    input_value = sgqlc.types.Field(String, graphql_name='inputValue')
-    status = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CollectionStatus)), graphql_name='status')
-
-
 class VersionFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
     __field_names__ = ('input_value', 'with_removed_versions')
@@ -433,9 +434,10 @@ class ArgsAndSettingsDescription(sgqlc.types.Type):
 
 class CrawlerData(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'title')
+    __field_names__ = ('id', 'title', 'name')
     id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
     title = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='title')
+    name = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='name')
 
 
 class CrawlerHistogram(sgqlc.types.Type):
@@ -489,12 +491,6 @@ class DeployedProject(sgqlc.types.Type):
     update_stats = sgqlc.types.Field(sgqlc.types.non_null('UpdateProjectStats'), graphql_name='updateStats')
 
 
-class ExternalSearchJob(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('job_id',)
-    job_id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='jobId')
-
-
 class FileData(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('id', 'file_name')
@@ -502,6 +498,37 @@ class FileData(sgqlc.types.Type):
     file_name = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='fileName')
 
 
+class InformationSource(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('id', 'url', 'site_name', 'status', 'periodic_job', 'job', 'crawler', 'error_message')
+    id = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='id')
+    url = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='url')
+    site_name = sgqlc.types.Field(String, graphql_name='siteName')
+    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
+    periodic_job = sgqlc.types.Field('PeriodicJob', graphql_name='periodicJob')
+    job = sgqlc.types.Field('Job', graphql_name='job')
+    crawler = sgqlc.types.Field('Crawler', graphql_name='crawler')
+    error_message = sgqlc.types.Field(String, graphql_name='errorMessage')
+
+
+class InformationSourceData(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('id', 'url', 'site_name', 'status', 'crawler', 'version_id')
+    id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
+    url = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='url')
+    site_name = sgqlc.types.Field(String, graphql_name='siteName')
+    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
+    crawler = sgqlc.types.Field(CrawlerData, graphql_name='crawler')
+    version_id = sgqlc.types.Field(ID, graphql_name='versionId')
+
+
+class InformationSourceLoaderStats(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('total_source_count', 'finished_source_count')
+    total_source_count = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='totalSourceCount')
+    finished_source_count = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='finishedSourceCount')
+
+
 class JobList(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('total', 'list_job')
@@ -524,12 +551,13 @@ class JobPagination(sgqlc.types.Type):
 
 class JobStats(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('jobs_count', 'total_time', 'items_scraped_count', 'requests_count', 'errors_count', 'jobs_with_errors_logs_count', 'jobs_with_critical_logs_count')
+    __field_names__ = ('jobs_count', 'total_time', 'items_scraped_count', 'requests_count', 'errors_count', 'duplicated_request_count', 'jobs_with_errors_logs_count', 'jobs_with_critical_logs_count')
     jobs_count = sgqlc.types.Field(Int, graphql_name='jobsCount')
     total_time = sgqlc.types.Field(Long, graphql_name='totalTime')
     items_scraped_count = sgqlc.types.Field(Long, graphql_name='itemsScrapedCount')
     requests_count = sgqlc.types.Field(Long, graphql_name='requestsCount')
     errors_count = sgqlc.types.Field(Int, graphql_name='errorsCount')
+    duplicated_request_count = sgqlc.types.Field(Int, graphql_name='duplicatedRequestCount')
     jobs_with_errors_logs_count = sgqlc.types.Field(Int, graphql_name='jobsWithErrorsLogsCount')
     jobs_with_critical_logs_count = sgqlc.types.Field(Int, graphql_name='jobsWithCriticalLogsCount')
 
@@ -570,7 +598,7 @@ class Metric(sgqlc.types.Type):
 
 class Mutation(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments_and_state', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'add_periodic_job', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_url_loader', 'delete_url_loader')
+    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments_and_state', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'add_periodic_job', 'run_periodic_jobs', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_information_source_loader', 'delete_information_source_loader')
     update_crawler = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='updateCrawler', args=sgqlc.types.ArgDict((
         ('crawler_update_input', sgqlc.types.Arg(sgqlc.types.non_null(CrawlerUpdateInput), graphql_name='crawlerUpdateInput', default=None)),
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
@@ -632,6 +660,10 @@ class Mutation(sgqlc.types.Type):
     )
     add_periodic_job = sgqlc.types.Field(sgqlc.types.non_null('PeriodicJob'), graphql_name='addPeriodicJob', args=sgqlc.types.ArgDict((
         ('periodic_job_input', sgqlc.types.Arg(sgqlc.types.non_null(PeriodicJobInput), graphql_name='periodicJobInput', default=None)),
+))
+    )
+    run_periodic_jobs = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('Job'))), graphql_name='runPeriodicJobs', args=sgqlc.types.ArgDict((
+        ('periodic_job_ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='periodicJobIds', default=None)),
 ))
     )
     update_enable_jobs_scheduling = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('PeriodicJob'))), graphql_name='updateEnableJobsScheduling', args=sgqlc.types.ArgDict((
@@ -689,16 +721,30 @@ class Mutation(sgqlc.types.Type):
         ('args', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='args', default=None)),
 ))
     )
-    add_url_loader = sgqlc.types.Field(sgqlc.types.non_null('UrlLoader'), graphql_name='addUrlLoader', args=sgqlc.types.ArgDict((
-        ('url_loader_input', sgqlc.types.Arg(sgqlc.types.non_null(UrlLoaderInput), graphql_name='urlLoaderInput', default=None)),
+    add_information_source_loader = sgqlc.types.Field(sgqlc.types.non_null('InformationSourceLoader'), graphql_name='addInformationSourceLoader', args=sgqlc.types.ArgDict((
+        ('information_source_loader_input', sgqlc.types.Arg(sgqlc.types.non_null(InformationSourceLoaderInput), graphql_name='informationSourceLoaderInput', default=None)),
 ))
     )
-    delete_url_loader = sgqlc.types.Field(sgqlc.types.non_null('State'), graphql_name='deleteUrlLoader', args=sgqlc.types.ArgDict((
+    delete_information_source_loader = sgqlc.types.Field(sgqlc.types.non_null('State'), graphql_name='deleteInformationSourceLoader', args=sgqlc.types.ArgDict((
         ('ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='ids', default=None)),
 ))
     )
 
 
+class PaginationInformationSource(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('total', 'list_information_source')
+    total = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='total')
+    list_information_source = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(InformationSource))), graphql_name='listInformationSource')
+
+
+class PaginationInformationSourceLoader(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('list_information_source_loader', 'total')
+    list_information_source_loader = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('InformationSourceLoader'))), graphql_name='listInformationSourceLoader')
+    total = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='total')
+
+
 class PaginationLog(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('total', 'log_list')
@@ -720,20 +766,6 @@ class PaginationRequest(sgqlc.types.Type):
     request_list = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('Request'))), graphql_name='requestList')
 
 
-class PaginationUrlLoader(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('list_url_loader', 'total')
-    list_url_loader = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('UrlLoader'))), graphql_name='listUrlLoader')
-    total = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='total')
-
-
-class PaginationUrlToLoader(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('total', 'list_url_to_loader')
-    total = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='total')
-    list_url_to_loader = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('UrlToLoader'))), graphql_name='listUrlToLoader')
-
-
 class PeriodicJobData(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('id', 'name')
@@ -790,10 +822,14 @@ class ProjectStats(sgqlc.types.Type):
 
 class Query(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('analytics', 'crawler', 'pagination_crawler', 'crawler_args_and_settings_description', 'credential', 'pagination_credential', 'job', 'pagination_job_logs', 'pagination_job_requests', 'pagination_job_metrics', 'pagination_job', 'periodic_job', 'pagination_periodic_job', 'pagination_periodic_job_logs', 'pagination_periodic_job_requests', 'pagination_periodic_job_metrics', 'periodic_job_by_input', 'project', 'pagination_project', 'project_args_and_settings_description', 'project_default_args_and_settings_description', 'url_loader', 'pagination_url_loader', 'url_to_loader', 'pagination_url_to_loader', 'version', 'pagination_versions_crawler', 'pagination_egg_file_versions_project', 'web_scraper_version_is_compatible')
+    __field_names__ = ('analytics', 'crawler', 'list_crawler', 'pagination_crawler', 'crawler_args_and_settings_description', 'credential', 'pagination_credential', 'job', 'list_job', 'pagination_job_logs', 'pagination_job_requests', 'pagination_job_metrics', 'pagination_job', 'periodic_job', 'pagination_periodic_job', 'pagination_periodic_job_logs', 'pagination_periodic_job_requests', 'pagination_periodic_job_metrics', 'check_periodic_job_by_input', 'project', 'pagination_project', 'project_args_and_settings_description', 'project_default_args_and_settings_description', 'information_source_loader', 'pagination_information_source_loader', 'information_source', 'pagination_information_source', 'version', 'list_version', 'pagination_versions_crawler', 'pagination_egg_file_versions_project', 'web_scraper_version_is_compatible')
     analytics = sgqlc.types.Field(sgqlc.types.non_null('Stats'), graphql_name='analytics')
     crawler = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='crawler', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
+))
+    )
+    list_crawler = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of('Crawler')), graphql_name='listCrawler', args=sgqlc.types.ArgDict((
+        ('ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='ids', default=None)),
 ))
     )
     pagination_crawler = sgqlc.types.Field(sgqlc.types.non_null(CrawlerPagination), graphql_name='paginationCrawler', args=sgqlc.types.ArgDict((
@@ -823,6 +859,10 @@ class Query(sgqlc.types.Type):
     )
     job = sgqlc.types.Field(sgqlc.types.non_null('Job'), graphql_name='job', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
+))
+    )
+    list_job = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of('Job')), graphql_name='listJob', args=sgqlc.types.ArgDict((
+        ('ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='ids', default=None)),
 ))
     )
     pagination_job_logs = sgqlc.types.Field(sgqlc.types.non_null(PaginationLog), graphql_name='paginationJobLogs', args=sgqlc.types.ArgDict((
@@ -898,7 +938,7 @@ class Query(sgqlc.types.Type):
         ('sort_field', sgqlc.types.Arg(MetricSorting, graphql_name='sortField', default=None)),
 ))
     )
-    periodic_job_by_input = sgqlc.types.Field(sgqlc.types.non_null('PeriodicJob'), graphql_name='periodicJobByInput', args=sgqlc.types.ArgDict((
+    check_periodic_job_by_input = sgqlc.types.Field('PeriodicJob', graphql_name='checkPeriodicJobByInput', args=sgqlc.types.ArgDict((
         ('periodic_job_input', sgqlc.types.Arg(sgqlc.types.non_null(PeriodicJobInput), graphql_name='periodicJobInput', default=None)),
 ))
     )
@@ -920,33 +960,37 @@ class Query(sgqlc.types.Type):
 ))
     )
     project_default_args_and_settings_description = sgqlc.types.Field(sgqlc.types.non_null(ArgsAndSettingsDescription), graphql_name='projectDefaultArgsAndSettingsDescription')
-    url_loader = sgqlc.types.Field(sgqlc.types.non_null('UrlLoader'), graphql_name='urlLoader', args=sgqlc.types.ArgDict((
+    information_source_loader = sgqlc.types.Field(sgqlc.types.non_null('InformationSourceLoader'), graphql_name='informationSourceLoader', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
 ))
     )
-    pagination_url_loader = sgqlc.types.Field(sgqlc.types.non_null(PaginationUrlLoader), graphql_name='paginationUrlLoader', args=sgqlc.types.ArgDict((
+    pagination_information_source_loader = sgqlc.types.Field(sgqlc.types.non_null(PaginationInformationSourceLoader), graphql_name='paginationInformationSourceLoader', args=sgqlc.types.ArgDict((
         ('limit', sgqlc.types.Arg(Int, graphql_name='limit', default=20)),
         ('offset', sgqlc.types.Arg(Int, graphql_name='offset', default=0)),
-        ('filter_settings', sgqlc.types.Arg(UrlLoaderFilterSettings, graphql_name='filterSettings', default={})),
-        ('sort_field', sgqlc.types.Arg(UrlLoaderSorting, graphql_name='sortField', default='id')),
+        ('filter_settings', sgqlc.types.Arg(InformationSourceLoaderFilterSettings, graphql_name='filterSettings', default={})),
+        ('sort_field', sgqlc.types.Arg(InformationSourceLoaderSorting, graphql_name='sortField', default='id')),
         ('direction', sgqlc.types.Arg(SortDirection, graphql_name='direction', default='descending')),
 ))
     )
-    url_to_loader = sgqlc.types.Field(sgqlc.types.non_null('UrlToLoader'), graphql_name='urlToLoader', args=sgqlc.types.ArgDict((
+    information_source = sgqlc.types.Field(sgqlc.types.non_null(InformationSource), graphql_name='informationSource', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
 ))
     )
-    pagination_url_to_loader = sgqlc.types.Field(sgqlc.types.non_null(PaginationUrlToLoader), graphql_name='paginationUrlToLoader', args=sgqlc.types.ArgDict((
+    pagination_information_source = sgqlc.types.Field(sgqlc.types.non_null(PaginationInformationSource), graphql_name='paginationInformationSource', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
         ('limit', sgqlc.types.Arg(Int, graphql_name='limit', default=20)),
         ('offset', sgqlc.types.Arg(Int, graphql_name='offset', default=0)),
-        ('filter_settings', sgqlc.types.Arg(UrlToLoaderFilterSettings, graphql_name='filterSettings', default={})),
-        ('sort_field', sgqlc.types.Arg(UrlToLoaderSorting, graphql_name='sortField', default='siteName')),
+        ('filter_settings', sgqlc.types.Arg(InformationSourceFilterSettings, graphql_name='filterSettings', default={})),
+        ('sort_field', sgqlc.types.Arg(InformationSourceSorting, graphql_name='sortField', default='id')),
         ('direction', sgqlc.types.Arg(SortDirection, graphql_name='direction', default='descending')),
 ))
     )
     version = sgqlc.types.Field(sgqlc.types.non_null('Version'), graphql_name='version', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
+))
+    )
+    list_version = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of('Version')), graphql_name='listVersion', args=sgqlc.types.ArgDict((
+        ('ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='ids', default=None)),
 ))
     )
     pagination_versions_crawler = sgqlc.types.Field(sgqlc.types.non_null('VersionPagination'), graphql_name='paginationVersionsCrawler', args=sgqlc.types.ArgDict((
@@ -1048,34 +1092,6 @@ class UpdateProjectStats(sgqlc.types.Type):
     stopped_periodic_ids = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(Long))), graphql_name='stoppedPeriodicIds')
 
 
-class UrlLoaderStats(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('total_url_count', 'finished_url_count')
-    total_url_count = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='totalUrlCount')
-    finished_url_count = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='finishedUrlCount')
-
-
-class UrlToLoader(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('url', 'site_name', 'status', 'periodic_job', 'job', 'crawler', 'error_message')
-    url = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='url')
-    site_name = sgqlc.types.Field(String, graphql_name='siteName')
-    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
-    periodic_job = sgqlc.types.Field('PeriodicJob', graphql_name='periodicJob')
-    job = sgqlc.types.Field('Job', graphql_name='job')
-    crawler = sgqlc.types.Field('Crawler', graphql_name='crawler')
-    error_message = sgqlc.types.Field(String, graphql_name='errorMessage')
-
-
-class UrlToLoaderData(sgqlc.types.Type):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'url', 'site_name', 'status')
-    id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
-    url = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='url')
-    site_name = sgqlc.types.Field(String, graphql_name='siteName')
-    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
-
-
 class User(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('id',)
@@ -1152,15 +1168,31 @@ class Credential(sgqlc.types.Type, RecordInterface):
     version = sgqlc.types.Field(sgqlc.types.non_null(Int), graphql_name='version')
 
 
+class InformationSourceLoader(sgqlc.types.Type, RecordInterface):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('id', 'file', 'sources', 'title', 'is_retrospective', 'retrospective_start', 'retrospective_end', 'actual_status', 'status', 'metrics')
+    id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
+    file = sgqlc.types.Field(FileData, graphql_name='file')
+    sources = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(InformationSourceData))), graphql_name='sources')
+    title = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='title')
+    is_retrospective = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='isRetrospective')
+    retrospective_start = sgqlc.types.Field(UnixTime, graphql_name='retrospectiveStart')
+    retrospective_end = sgqlc.types.Field(UnixTime, graphql_name='retrospectiveEnd')
+    actual_status = sgqlc.types.Field(sgqlc.types.non_null(InformationSourceLoaderActualStatus), graphql_name='actualStatus')
+    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
+    metrics = sgqlc.types.Field(sgqlc.types.non_null(InformationSourceLoaderStats), graphql_name='metrics')
+
+
 class Job(sgqlc.types.Type, RecordInterface):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'status', 'priority', 'start_time', 'end_time', 'collection_status', 'crawler', 'project', 'version', 'periodic', 'settings', 'args', 'metrics', 'job_stats', 'histogram', 'schema', 'external_search_job')
+    __field_names__ = ('id', 'status', 'priority', 'start_time', 'end_time', 'collection_status', 'is_noise', 'crawler', 'project', 'version', 'periodic', 'settings', 'args', 'metrics', 'job_stats', 'histogram_requests', 'histogram_items', 'schema')
     id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
     status = sgqlc.types.Field(sgqlc.types.non_null(JobStatus), graphql_name='status')
     priority = sgqlc.types.Field(sgqlc.types.non_null(JobPriorityType), graphql_name='priority')
     start_time = sgqlc.types.Field(Long, graphql_name='startTime')
     end_time = sgqlc.types.Field(Long, graphql_name='endTime')
     collection_status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='collectionStatus')
+    is_noise = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='isNoise')
     crawler = sgqlc.types.Field(sgqlc.types.non_null(CrawlerData), graphql_name='crawler')
     project = sgqlc.types.Field(sgqlc.types.non_null(ProjectData), graphql_name='project')
     version = sgqlc.types.Field(sgqlc.types.non_null(VersionData), graphql_name='version')
@@ -1169,9 +1201,9 @@ class Job(sgqlc.types.Type, RecordInterface):
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='args')
     metrics = sgqlc.types.Field(sgqlc.types.non_null(JobMetrics), graphql_name='metrics')
     job_stats = sgqlc.types.Field(JobStats, graphql_name='jobStats')
-    histogram = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(DateHistogramBucket))), graphql_name='histogram')
+    histogram_requests = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(DateHistogramBucket))), graphql_name='histogramRequests')
+    histogram_items = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(DateHistogramBucket))), graphql_name='histogramItems')
     schema = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='schema')
-    external_search_job = sgqlc.types.Field(sgqlc.types.non_null(ExternalSearchJob), graphql_name='externalSearchJob')
 
 
 class PeriodicJob(sgqlc.types.Type, RecordInterface):
@@ -1235,21 +1267,6 @@ class Project(sgqlc.types.Type, RecordInterface):
     egg_file = sgqlc.types.Field(String, graphql_name='eggFile')
 
 
-class UrlLoader(sgqlc.types.Type, RecordInterface):
-    __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'file', 'urls', 'title', 'is_retrospective', 'retrospective_start', 'retrospective_end', 'actual_status', 'status', 'metrics')
-    id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
-    file = sgqlc.types.Field(FileData, graphql_name='file')
-    urls = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(UrlToLoaderData))), graphql_name='urls')
-    title = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='title')
-    is_retrospective = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='isRetrospective')
-    retrospective_start = sgqlc.types.Field(UnixTime, graphql_name='retrospectiveStart')
-    retrospective_end = sgqlc.types.Field(UnixTime, graphql_name='retrospectiveEnd')
-    actual_status = sgqlc.types.Field(sgqlc.types.non_null(UrlLoaderActualStatus), graphql_name='actualStatus')
-    status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='status')
-    metrics = sgqlc.types.Field(sgqlc.types.non_null(UrlLoaderStats), graphql_name='metrics')
-
-
 class Version(sgqlc.types.Type, RecordInterface):
     __schema__ = crawlers_api_schema
     __field_names__ = ('id', 'version_name', 'project_id', 'status')
